@@ -36,10 +36,14 @@ class CLICommands(str, Enum):
     MEMORY = "memory"
     MONITOR = "monitor"
     CONFIG = "config"
+    CONFIGURE = "configure"
     AGGREGATE = "aggregate"
+    ANALYZE = "analyze"
+    ANALYZE_CODE = "analyze-code"
     CLEANUP = "cleanup-memory"
     MCP = "mcp"
     DOCTOR = "doctor"
+    DASHBOARD = "dashboard"
 
     def with_prefix(self, prefix: CLIPrefix = CLIPrefix.MPM) -> str:
         """Get command with prefix."""
@@ -96,6 +100,15 @@ class MonitorCommands(str, Enum):
     PORT = "port"
 
 
+class DashboardCommands(str, Enum):
+    """Dashboard subcommand constants."""
+
+    START = "start"
+    STOP = "stop"
+    STATUS = "status"
+    OPEN = "open"
+
+
 class ConfigCommands(str, Enum):
     """Config subcommand constants."""
 
@@ -216,7 +229,7 @@ class Paths(str, Enum):
 
     CLAUDE_AGENTS_DIR = ".claude/agents"
     CLAUDE_CONFIG_DIR = ".claude"
-    MPM_LOG_DIR = ".claude-mpm/logs"
+    MPM_LOG_DIR = ".claude-mpm/logs/mpm"
     MPM_SESSION_DIR = ".claude-mpm/session"
     MPM_PROMPTS_DIR = ".claude-mpm/prompts"
 
