@@ -367,9 +367,17 @@ class UnifiedAgentRegistry:
                                 break
                             project_root = project_root.parent
 
-                    # Extract tags
+                    # Extract tags (handle both list and comma-separated string formats)
                     if "metadata" in data:
-                        tags = data["metadata"].get("tags", [])
+                        tags_raw = data["metadata"].get("tags", [])
+                        if isinstance(tags_raw, str):
+                            tags = [
+                                tag.strip()
+                                for tag in tags_raw.split(",")
+                                if tag.strip()
+                            ]
+                        else:
+                            tags = tags_raw if isinstance(tags_raw, list) else []
 
                 except Exception as e:
                     logger.debug(
@@ -462,8 +470,14 @@ class UnifiedAgentRegistry:
                         "specializations", data.get("specializations", [])
                     )
 
-                    # Extract tags as specializations if present
-                    tags = metadata.get("tags", [])
+                    # Extract tags as specializations if present (handle both formats)
+                    tags_raw = metadata.get("tags", [])
+                    if isinstance(tags_raw, str):
+                        tags = [
+                            tag.strip() for tag in tags_raw.split(",") if tag.strip()
+                        ]
+                    else:
+                        tags = tags_raw if isinstance(tags_raw, list) else []
                     if tags and not specializations:
                         specializations = tags
                 else:
