@@ -218,7 +218,7 @@ class CodeAnalysisEventHandler(BaseEventHandler):
 
         # SECURITY: Validate the requested path
         # Allow access to the explicitly chosen working directory and its subdirectories
-        requested_path = Path(path).absolute()
+        Path(path).absolute()
 
         # For now, we trust the frontend to send valid paths
         # In production, you might want to maintain a server-side list of allowed directories
@@ -268,7 +268,9 @@ class CodeAnalysisEventHandler(BaseEventHandler):
                 self.logger.info("Creating CodeTreeAnalyzer")
                 # Pass emit_events=False to prevent duplicate events from the analyzer
                 # The emitter will still work but the analyzer won't create its own stdout emitter
-                self.code_analyzer = CodeTreeAnalyzer(emit_events=False, emitter=emitter)
+                self.code_analyzer = CodeTreeAnalyzer(
+                    emit_events=False, emitter=emitter
+                )
 
             # Use the provided path as-is - the frontend sends the absolute path
             # Make sure we're using an absolute path
@@ -456,7 +458,9 @@ class CodeAnalysisEventHandler(BaseEventHandler):
                 self.logger.info("Creating CodeTreeAnalyzer")
                 # Pass emit_events=False to prevent duplicate events from the analyzer
                 # The emitter will still work but the analyzer won't create its own stdout emitter
-                self.code_analyzer = CodeTreeAnalyzer(emit_events=False, emitter=emitter)
+                self.code_analyzer = CodeTreeAnalyzer(
+                    emit_events=False, emitter=emitter
+                )
 
             # Discover directory
             result = self.code_analyzer.discover_directory(path, ignore_patterns)
@@ -466,11 +470,13 @@ class CodeAnalysisEventHandler(BaseEventHandler):
                 f"Discovery result for {path}: {len(result.get('children', []))} children found"
             )
             self.logger.debug(f"Full result: {result}")
-            
+
             # DEBUG: Log exact children being sent
-            children = result.get('children', [])
+            children = result.get("children", [])
             if children:
-                self.logger.info(f"Children being sent: {[child.get('name') for child in children]}")
+                self.logger.info(
+                    f"Children being sent: {[child.get('name') for child in children]}"
+                )
                 self.logger.info(f"Full children data: {children}")
             else:
                 self.logger.warning(f"No children found for {path}")
@@ -483,9 +489,16 @@ class CodeAnalysisEventHandler(BaseEventHandler):
                 "type": result.get("type", "directory"),
                 "children": children,  # Send children array directly
             }
-            
-            # Log the exact data being sent
-            self.logger.info(f"Sending response data: {response_data}")
+
+            # CRITICAL DEBUG: Log exact JSON that will be sent
+            import json
+
+            self.logger.info(
+                f"Sending response data (JSON): {json.dumps(response_data, indent=2)}"
+            )
+            self.logger.info(
+                f"Children count in response: {len(response_data.get('children', []))}"
+            )
 
             # Send result with correct event name (using colons, not dots!)
             # Include both absolute path and relative name for frontend compatibility
@@ -519,7 +532,7 @@ class CodeAnalysisEventHandler(BaseEventHandler):
 
         path = data.get("path")
         request_id = data.get("request_id")
-        show_hidden_files = data.get("show_hidden_files", False)
+        data.get("show_hidden_files", False)
 
         if not path:
             await self.server.core.sio.emit(
@@ -578,8 +591,11 @@ class CodeAnalysisEventHandler(BaseEventHandler):
             return
 
         try:
+            self.logger.info(f"Starting file analysis for: {path}")
+
             # Ensure analyzer exists
             if not self.code_analyzer:
+                self.logger.info("Creating new CodeTreeAnalyzer instance")
                 emitter = CodeTreeEventEmitter(use_stdout=False)
                 # Override emit method to send to Socket.IO
                 original_emit = emitter.emit
@@ -614,24 +630,45 @@ class CodeAnalysisEventHandler(BaseEventHandler):
                 self.logger.info("Creating CodeTreeAnalyzer")
                 # Pass emit_events=False to prevent duplicate events from the analyzer
                 # The emitter will still work but the analyzer won't create its own stdout emitter
-                self.code_analyzer = CodeTreeAnalyzer(emit_events=False, emitter=emitter)
+                self.code_analyzer = CodeTreeAnalyzer(
+                    emit_events=False, emitter=emitter
+                )
+                self.logger.info("CodeTreeAnalyzer created successfully")
 
             # Analyze file
+            self.logger.info(f"Calling analyze_file for: {path}")
             result = self.code_analyzer.analyze_file(path)
+            self.logger.info(
+                f"Analysis complete. Result keys: {list(result.keys()) if result else 'None'}"
+            )
+
+            if result:
+                self.logger.info(
+                    f"Analysis result: elements={len(result.get('elements', []))}, nodes={len(result.get('nodes', []))}"
+                )
+            else:
+                self.logger.warning("Analysis returned None or empty result")
 
             # Send result with correct event name (using colons, not dots!)
+            response_data = {
+                "request_id": request_id,
+                "path": path,
+                **result,
+            }
+
+            self.logger.info(f"Emitting code:file:analyzed event to {sid}")
             await self.server.core.sio.emit(
                 "code:file:analyzed",
-                {
-                    "request_id": request_id,
-                    "path": path,
-                    **result,
-                },
+                response_data,
                 room=sid,
             )
+            self.logger.info("Event emitted successfully")
 
         except Exception as e:
             self.logger.error(f"Error analyzing file {path}: {e}")
+            import traceback
+
+            self.logger.error(f"Full traceback: {traceback.format_exc()}")
             await self.server.core.sio.emit(
                 "code:analysis:error",
                 {
