@@ -500,6 +500,36 @@ class PythonAnalyzer:
                         )
                     )
 
+            def visit_Assign(self, node):
+                # Handle module-level variable assignments
+                if self.current_class is None:  # Only module-level assignments
+                    for target in node.targets:
+                        if isinstance(target, ast.Name):
+                            var_node = CodeNode(
+                                file_path=str(file_path),
+                                node_type="variable",
+                                name=target.id,
+                                line_start=node.lineno,
+                                line_end=node.end_lineno or node.lineno,
+                                parent=self.parent_name,
+                                complexity=0,
+                                signature=f"{target.id} = ...",
+                            )
+                            nodes.append(var_node)
+
+                            # Emit event if emitter is available
+                            if self.emitter:
+                                self.emitter.emit_node(
+                                    CodeNodeEvent(
+                                        file_path=str(file_path),
+                                        node_type="variable",
+                                        name=target.id,
+                                        line_start=node.lineno,
+                                        line_end=node.end_lineno or node.lineno,
+                                        parent=self.parent_name,
+                                    )
+                                )
+
             def visit_AsyncFunctionDef(self, node):
                 self.visit_FunctionDef(node)
 
@@ -578,6 +608,24 @@ class PythonAnalyzer:
 
         return nodes
 
+    def _get_assignment_signature(self, node: ast.Assign, var_name: str) -> str:
+        """Get assignment signature string."""
+        try:
+            # Try to get a simple representation of the value
+            if isinstance(node.value, ast.Constant):
+                if isinstance(node.value.value, str):
+                    return f'{var_name} = "{node.value.value}"'
+                return f"{var_name} = {node.value.value}"
+            if isinstance(node.value, ast.Name):
+                return f"{var_name} = {node.value.id}"
+            if isinstance(node.value, ast.List):
+                return f"{var_name} = [...]"
+            if isinstance(node.value, ast.Dict):
+                return f"{var_name} = {{...}}"
+            return f"{var_name} = ..."
+        except:
+            return f"{var_name} = ..."
+
 
 class MultiLanguageAnalyzer:
     """Analyzes multiple programming languages using tree-sitter.
@@ -791,11 +839,11 @@ class CodeTreeAnalyzer:
     CODE_EXTENSIONS = {
         ".py",
         ".js",
-        ".jsx",  
+        ".jsx",
         ".ts",
         ".tsx",
-        ".mjs",    # Added missing extension
-        ".cjs",    # Added missing extension
+        ".mjs",  # Added missing extension
+        ".cjs",  # Added missing extension
         ".java",
         ".cpp",
         ".c",
@@ -1219,7 +1267,7 @@ class CodeTreeAnalyzer:
                         continue
                     if self.has_code_files(item, depth, current_depth + 1):
                         return True
-                    
+
         except (PermissionError, OSError):
             pass
 
@@ -1240,7 +1288,7 @@ class CodeTreeAnalyzer:
         # CRITICAL FIX: Use the directory parameter as the base for relative paths
         # NOT the current working directory. This ensures we only show items
         # within the requested directory, not parent directories.
-        working_dir = Path(directory).absolute()
+        Path(directory).absolute()
 
         # Emit discovery start event
         if self.emitter:
@@ -1314,7 +1362,7 @@ class CodeTreeAnalyzer:
 
                 if item.is_dir():
                     # Check if directory contains code files (recursively checking subdirectories)
-                    # Important: We want to include directories even if they only have code 
+                    # Important: We want to include directories even if they only have code
                     # in subdirectories (like src/claude_mpm/*.py)
                     if not self.has_code_files(item, depth=5):
                         if self.emitter:
@@ -1461,8 +1509,7 @@ class CodeTreeAnalyzer:
             self._last_working_dir = directory.parent
 
         # The discover_top_level method will emit all the INFO events
-        result = self.discover_top_level(directory, ignore_patterns)
-        return result
+        return self.discover_top_level(directory, ignore_patterns)
 
     def analyze_file(self, file_path: str) -> Dict[str, Any]:
         """Analyze a specific file and return its AST structure.
@@ -1530,7 +1577,7 @@ class CodeTreeAnalyzer:
 
             if language == "python":
                 analyzer = self.python_analyzer
-            elif language == "javascript" or language == "typescript":
+            elif language in {"javascript", "typescript"}:
                 analyzer = self.javascript_analyzer
             else:
                 analyzer = self.generic_analyzer
@@ -1626,53 +1673,95 @@ class CodeTreeAnalyzer:
 
                 self.emitter.emit_file_analyzed(file_path, filtered_nodes, duration)
 
+        # Prepare the nodes data
+        final_nodes = (
+            filtered_nodes
+            if "filtered_nodes" in locals()
+            else [
+                {
+                    "name": n.name,
+                    "type": n.node_type,
+                    "line_start": n.line_start,
+                    "line_end": n.line_end,
+                    "complexity": n.complexity,
+                    "has_docstring": n.has_docstring,
+                    "signature": n.signature,
+                }
+                for n in nodes
+                if not self._is_internal_node(n)
+            ]
+        )
+
+        # Convert nodes to elements format for dashboard compatibility
+        elements = []
+        for node in final_nodes:
+            element = {
+                "name": node["name"],
+                "type": node["type"],
+                "line": node["line_start"],  # Dashboard expects 'line' not 'line_start'
+                "complexity": node["complexity"],
+                "signature": node.get("signature", ""),
+                "has_docstring": node.get("has_docstring", False),
+            }
+            # Add methods if it's a class (for expandable tree)
+            if node["type"] == "class":
+                element["methods"] = []  # Could be populated with class methods
+            elements.append(element)
+
         return {
             "path": file_path,
             "language": language,
-            "nodes": (
-                filtered_nodes
-                if "filtered_nodes" in locals()
-                else [
-                    {
-                        "name": n.name,
-                        "type": n.node_type,
-                        "line_start": n.line_start,
-                        "line_end": n.line_end,
-                        "complexity": n.complexity,
-                        "has_docstring": n.has_docstring,
-                        "signature": n.signature,
-                    }
-                    for n in nodes
-                    if not self._is_internal_node(n)
-                ]
-            ),
+            "nodes": final_nodes,  # Keep for backward compatibility
+            "elements": elements,  # Add for dashboard compatibility
+            "complexity": sum(e["complexity"] for e in elements),
+            "lines": len(elements),  # Simple line count approximation
+            "stats": {
+                "classes": len([e for e in elements if e["type"] == "class"]),
+                "functions": len([e for e in elements if e["type"] == "function"]),
+                "methods": len([e for e in elements if e["type"] == "method"]),
+                "variables": len([e for e in elements if e["type"] == "variable"]),
+                "imports": len([e for e in elements if e["type"] == "import"]),
+                "total": len(elements),
+            },
         }
 
     def _is_internal_node(self, node: CodeNode) -> bool:
         """Check if node is an internal function that should be filtered."""
-        # Filter patterns for internal functions
-        internal_patterns = [
-            "handle",  # Event handlers
-            "on_",  # Event callbacks
-            "_",  # Private methods
-            "get_",  # Simple getters
-            "set_",  # Simple setters
-            "__",  # Python magic methods
-        ]
-
-        name_lower = node.name.lower()
-
-        # Don't filter classes or important public methods
+        # Don't filter classes - always show them
         if node.node_type == "class":
             return False
 
-        # Check patterns
-        for pattern in internal_patterns:
-            if name_lower.startswith(pattern):
-                # Exception: include __init__ methods
-                if node.name == "__init__":
-                    return False
-                return True
+        # Don't filter variables or imports - they're useful for tree view
+        if node.node_type in ["variable", "import"]:
+            return False
+
+        name_lower = node.name.lower()
+
+        # Filter only very specific internal patterns
+        # Be more conservative - only filter obvious internal handlers
+        if name_lower.startswith(("handle_", "on_")):
+            return True
+
+        # Filter Python magic methods except important ones
+        if name_lower.startswith("__") and name_lower.endswith("__"):
+            # Keep important magic methods
+            important_magic = [
+                "__init__",
+                "__call__",
+                "__enter__",
+                "__exit__",
+                "__str__",
+                "__repr__",
+            ]
+            return node.name not in important_magic
+
+        # Filter very generic getters/setters only if they're trivial
+        if (name_lower.startswith(("get_", "set_"))) and len(node.name) <= 8:
+            return True
+
+        # Don't filter single underscore functions - they're often important
+        # (like _setup_logging, _validate_input, etc.)
+        return False
 
         return False
 
